@@ -1105,7 +1105,7 @@ class Line(ModelSQL, ModelView):
                     & table.move.in_(move.join(period,
                             condition=move.period == period.id
                             ).select(move.id,
-                            where=(move.fiscalyear == fiscalyear_id)
+                            where=(period.fiscalyear == fiscalyear_id)
                             & (move.date <= Transaction().context['date'])
                             & (move.state == 'posted'))),
                     [f.id for f in fiscalyears])
@@ -1127,9 +1127,9 @@ class Line(ModelSQL, ModelView):
                 return ((table.state != 'draft')
                     & table.move.in_(
                             move.select(move.id,
-                                where=period.in_(
+                                where=move.period.in_(
                                     Transaction().context['periods'])
-                                & move.state == 'posted')),
+                                & (move.state == 'posted'))),
                     fiscalyear_ids)
             else:
                 return ((table.state != 'draft')
@@ -1155,7 +1155,7 @@ class Line(ModelSQL, ModelView):
                                 period.select(period.id,
                                     where=period.fiscalyear.in_(
                                         fiscalyear_ids)))
-                            & move.state == 'posted')),
+                            & (move.state == 'posted'))),
                     fiscalyear_ids)
             else:
                 return ((table.state != 'draft')
